.. _usage-metadata:


Metadata
====================
The ``dhlab.metadata`` subpackage contains functionality for fetching metadata from objects in
`NB Digital`_.





Use
-------
Import :doc:`dhlab.metadata <generated/metadata.metadata>` functions like this:



.. code-block::

   from dhlab.metadata import ...

-----------------------------------

..
    References and subpages...

.. _NB Digital: https://www.nb.no/search


